@@ -3,6 +3,7 @@
 import sys
 import os
 import glob
+import optparse
 import gtk
 import tl.eggdeps.graph
 
@@ -219,8 +220,10 @@ class MainWindow(object):
             return False # always allow expansion of the current row
         return self.model._node_with_extra_info(path)[2]
 
-    def load_tree(self, specs=()):
-        graph = ExtraDiscerningGraph(show=lambda name: name != 'setuptools')
+    def load_tree(self, opts, specs):
+        def show(name):
+            return name not in opts.ignore
+        graph = ExtraDiscerningGraph(show=show)
         if specs:
             self.window.set_title("Egg dependencies for %s" % " ".join(specs))
             graph.from_specifications(*specs)
@@ -232,8 +235,14 @@ class MainWindow(object):
 
 
 def main():
+    parser = optparse.OptionParser("usage: %prog [options] [specifications]")
+    parser.add_option("-i", "--ignore",
+                      dest="ignore", action="append",
+                      default=['setuptools'],
+                      help="project names to ignore")
+    opts, args = parser.parse_args()
     win = MainWindow()
-    win.load_tree(sys.argv[1:])
+    win.load_tree(opts, args)
     gtk.main()
 
 
